@@ -221,6 +221,17 @@ sub compose {
 	0 .. $#{$bp})
 	or return $self;
 
+    ##
+    ## --matchcount
+    ##
+    if (my $countcheck = $self->{countcheck}) {
+	@effective_index = do {
+	    grep { $countcheck->(int(@{$mp->[$_][POSI_LIST]})) }
+	    @effective_index;
+	}
+	or return $self;
+    }
+
     ##
     ## --block with -ABC option
     ##
